# Generated by Django 3.2.13 on 2022-05-21 06:27

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_omise', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='chargeschedule',
            name='card',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='charge_schedules', to='django_omise.card'),
        ),
    ]
